==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterSpecFluent<A extends EnvoyFilterSpecFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterSpecFluent() {
  }
  public EnvoyFilterSpecFluent(EnvoyFilterSpec instance) {
    instance = (instance != null ? instance : new EnvoyFilterSpec());

    if (instance != null) {
      this.withConfigPatches(instance.getConfigPatches());
      this.withPriority(instance.getPriority());
      this.withWorkloadSelector(instance.getWorkloadSelector());
      this.withConfigPatches(instance.getConfigPatches());
      this.withPriority(instance.getPriority());
      this.withWorkloadSelector(instance.getWorkloadSelector());
    }
  }
  private ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder> configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();
  private Integer priority;
  private WorkloadSelectorBuilder workloadSelector;
  public A addToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);
    if (index < 0 || index >= configPatches.size()) { _visitables.get("configPatches").add(builder); configPatches.add(builder); } else { _visitables.get("configPatches").add(index, builder); configPatches.add(index, builder);}
    return (A)this;
  }
  public A setToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);
    if (index < 0 || index >= configPatches.size()) { _visitables.get("configPatches").add(builder); configPatches.add(builder); } else { _visitables.get("configPatches").set(index, builder); configPatches.set(index, builder);}
    return (A)this;
  }
  public A addToConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  public A addAllToConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  public A removeFromConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    if (this.configPatches == null) return (A)this;
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder); this.configPatches.remove(builder);} return (A)this;
  }
  public A removeAllFromConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    if (this.configPatches == null) return (A)this;
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder); this.configPatches.remove(builder);} return (A)this;
  }
  public A removeMatchingFromConfigPatches(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    if (configPatches == null) return (A) this;
    final Iterator<EnvoyFilterEnvoyConfigObjectPatchBuilder> each = configPatches.iterator();
    final List visitables = _visitables.get("configPatches");
    while (each.hasNext()) {
      EnvoyFilterEnvoyConfigObjectPatchBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<EnvoyFilterEnvoyConfigObjectPatch> buildConfigPatches() {
    return configPatches != null ? build(configPatches) : null;
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildConfigPatch(int index) {
    return this.configPatches.get(index).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildFirstConfigPatch() {
    return this.configPatches.get(0).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildLastConfigPatch() {
    return this.configPatches.get(configPatches.size() - 1).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConfigPatches(List<EnvoyFilterEnvoyConfigObjectPatch> configPatches) {
    if (this.configPatches != null) { _visitables.get("configPatches").clear();}
    if (configPatches != null) {this.configPatches = new ArrayList(); for (EnvoyFilterEnvoyConfigObjectPatch item : configPatches){this.addToConfigPatches(item);}} else { this.configPatches = null;} return (A) this;
  }
  public A withConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... configPatches) {
    if (this.configPatches != null) {this.configPatches.clear(); _visitables.remove("configPatches"); }
    if (configPatches != null) {for (EnvoyFilterEnvoyConfigObjectPatch item :configPatches){ this.addToConfigPatches(item);}} return (A) this;
  }
  public boolean hasConfigPatches() {
    return configPatches != null && !configPatches.isEmpty();
  }
  public ConfigPatchesNested<A> addNewConfigPatch() {
    return new ConfigPatchesNested(-1, null);
  }
  public ConfigPatchesNested<A> addNewConfigPatchLike(EnvoyFilterEnvoyConfigObjectPatch item) {
    return new ConfigPatchesNested(-1, item);
  }
  public ConfigPatchesNested<A> setNewConfigPatchLike(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    return new ConfigPatchesNested(index, item);
  }
  public ConfigPatchesNested<A> editConfigPatch(int index) {
    if (configPatches.size() <= index) throw new RuntimeException("Can't edit configPatches. Index exceeds size.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public ConfigPatchesNested<A> editFirstConfigPatch() {
    if (configPatches.size() == 0) throw new RuntimeException("Can't edit first configPatches. The list is empty.");
    return setNewConfigPatchLike(0, buildConfigPatch(0));
  }
  public ConfigPatchesNested<A> editLastConfigPatch() {
    int index = configPatches.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last configPatches. The list is empty.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public ConfigPatchesNested<A> editMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    int index = -1;
    for (int i=0;i<configPatches.size();i++) { 
    if (predicate.test(configPatches.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching configPatches. No match found.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public Integer getPriority() {
    return this.priority;
  }
  public A withPriority(Integer priority) {
    this.priority=priority; return (A) this;
  }
  public boolean hasPriority() {
    return this.priority != null;
  }
  public WorkloadSelector buildWorkloadSelector() {
    return this.workloadSelector!=null ?this.workloadSelector.build():null;
  }
  public A withWorkloadSelector(WorkloadSelector workloadSelector) {
    _visitables.get("workloadSelector").remove(this.workloadSelector);
    if (workloadSelector!=null){ this.workloadSelector= new WorkloadSelectorBuilder(workloadSelector); _visitables.get("workloadSelector").add(this.workloadSelector);} else { this.workloadSelector = null; _visitables.get("workloadSelector").remove(this.workloadSelector); } return (A) this;
  }
  public boolean hasWorkloadSelector() {
    return this.workloadSelector != null;
  }
  public WorkloadSelectorNested<A> withNewWorkloadSelector() {
    return new WorkloadSelectorNested(null);
  }
  public WorkloadSelectorNested<A> withNewWorkloadSelectorLike(WorkloadSelector item) {
    return new WorkloadSelectorNested(item);
  }
  public WorkloadSelectorNested<A> editWorkloadSelector() {
    return withNewWorkloadSelectorLike(java.util.Optional.ofNullable(buildWorkloadSelector()).orElse(null));
  }
  public WorkloadSelectorNested<A> editOrNewWorkloadSelector() {
    return withNewWorkloadSelectorLike(java.util.Optional.ofNullable(buildWorkloadSelector()).orElse(new WorkloadSelectorBuilder().build()));
  }
  public WorkloadSelectorNested<A> editOrNewWorkloadSelectorLike(WorkloadSelector item) {
    return withNewWorkloadSelectorLike(java.util.Optional.ofNullable(buildWorkloadSelector()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterSpecFluent that = (EnvoyFilterSpecFluent) o;
    if (!java.util.Objects.equals(configPatches, that.configPatches)) return false;

    if (!java.util.Objects.equals(priority, that.priority)) return false;

    if (!java.util.Objects.equals(workloadSelector, that.workloadSelector)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configPatches,  priority,  workloadSelector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configPatches != null && !configPatches.isEmpty()) { sb.append("configPatches:"); sb.append(configPatches + ","); }
    if (priority != null) { sb.append("priority:"); sb.append(priority + ","); }
    if (workloadSelector != null) { sb.append("workloadSelector:"); sb.append(workloadSelector); }
    sb.append("}");
    return sb.toString();
  }
  public class ConfigPatchesNested<N> extends EnvoyFilterEnvoyConfigObjectPatchFluent<ConfigPatchesNested<N>> implements Nested<N>{
    ConfigPatchesNested(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
      this.index = index;
      this.builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder;
    int index;
    public N and() {
      return (N) EnvoyFilterSpecFluent.this.setToConfigPatches(index,builder.build());
    }
    public N endConfigPatch() {
      return and();
    }
    
  }
  public class WorkloadSelectorNested<N> extends WorkloadSelectorFluent<WorkloadSelectorNested<N>> implements Nested<N>{
    WorkloadSelectorNested(WorkloadSelector item) {
      this.builder = new WorkloadSelectorBuilder(this, item);
    }
    WorkloadSelectorBuilder builder;
    public N and() {
      return (N) EnvoyFilterSpecFluent.this.withWorkloadSelector(builder.build());
    }
    public N endWorkloadSelector() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EnvoyFilterSpecFluent<A extends EnvoyFilterSpecFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterSpecFluent() {
  }
  
  public EnvoyFilterSpecFluent(EnvoyFilterSpec instance) {
    this.copyInstance(instance);
  }
  private ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder> configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();
  private Integer priority;
  private WorkloadSelectorBuilder workloadSelector;
  
  protected void copyInstance(EnvoyFilterSpec instance) {
    instance = (instance != null ? instance : new EnvoyFilterSpec());
  
    if (instance != null) {
        this.withConfigPatches(instance.getConfigPatches());
        this.withPriority(instance.getPriority());
        this.withWorkloadSelector(instance.getWorkloadSelector());
        this.withConfigPatches(instance.getConfigPatches());
        this.withPriority(instance.getPriority());
        this.withWorkloadSelector(instance.getWorkloadSelector());
      }
  }
  
  public A addToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);
    if (index < 0 || index >= configPatches.size()) { _visitables.get("configPatches").add(builder); configPatches.add(builder); } else { _visitables.get("configPatches").add(index, builder); configPatches.add(index, builder);}
    return (A)this;
  }
  
  public A setToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);
    if (index < 0 || index >= configPatches.size()) { _visitables.get("configPatches").add(builder); configPatches.add(builder); } else { _visitables.get("configPatches").set(index, builder); configPatches.set(index, builder);}
    return (A)this;
  }
  
  public A addToConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  
  public A addAllToConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  
  public A removeFromConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    if (this.configPatches == null) return (A)this;
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder); this.configPatches.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    if (this.configPatches == null) return (A)this;
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder); this.configPatches.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConfigPatches(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    if (configPatches == null) return (A) this;
    final Iterator<EnvoyFilterEnvoyConfigObjectPatchBuilder> each = configPatches.iterator();
    final List visitables = _visitables.get("configPatches");
    while (each.hasNext()) {
      EnvoyFilterEnvoyConfigObjectPatchBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<EnvoyFilterEnvoyConfigObjectPatch> buildConfigPatches() {
    return configPatches != null ? build(configPatches) : null;
  }
  
  public EnvoyFilterEnvoyConfigObjectPatch buildConfigPatch(int index) {
    return this.configPatches.get(index).build();
  }
  
  public EnvoyFilterEnvoyConfigObjectPatch buildFirstConfigPatch() {
    return this.configPatches.get(0).build();
  }
  
  public EnvoyFilterEnvoyConfigObjectPatch buildLastConfigPatch() {
    return this.configPatches.get(configPatches.size() - 1).build();
  }
  
  public EnvoyFilterEnvoyConfigObjectPatch buildMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withConfigPatches(List<EnvoyFilterEnvoyConfigObjectPatch> configPatches) {
    if (this.configPatches != null) { _visitables.get("configPatches").clear();}
    if (configPatches != null) {this.configPatches = new ArrayList(); for (EnvoyFilterEnvoyConfigObjectPatch item : configPatches){this.addToConfigPatches(item);}} else { this.configPatches = null;} return (A) this;
  }
  
  public A withConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... configPatches) {
    if (this.configPatches != null) {this.configPatches.clear(); _visitables.remove("configPatches"); }
    if (configPatches != null) {for (EnvoyFilterEnvoyConfigObjectPatch item :configPatches){ this.addToConfigPatches(item);}} return (A) this;
  }
  
  public boolean hasConfigPatches() {
    return configPatches != null && !configPatches.isEmpty();
  }
  
  public ConfigPatchesNested<A> addNewConfigPatch() {
    return new ConfigPatchesNested(-1, null);
  }
  
  public ConfigPatchesNested<A> addNewConfigPatchLike(EnvoyFilterEnvoyConfigObjectPatch item) {
    return new ConfigPatchesNested(-1, item);
  }
  
  public ConfigPatchesNested<A> setNewConfigPatchLike(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    return new ConfigPatchesNested(index, item);
  }
  
  public ConfigPatchesNested<A> editConfigPatch(int index) {
    if (configPatches.size() <= index) throw new RuntimeException("Can't edit configPatches. Index exceeds size.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  
  public ConfigPatchesNested<A> editFirstConfigPatch() {
    if (configPatches.size() == 0) throw new RuntimeException("Can't edit first configPatches. The list is empty.");
    return setNewConfigPatchLike(0, buildConfigPatch(0));
  }
  
  public ConfigPatchesNested<A> editLastConfigPatch() {
    int index = configPatches.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last configPatches. The list is empty.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  
  public ConfigPatchesNested<A> editMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    int index = -1;
    for (int i=0;i<configPatches.size();i++) { 
    if (predicate.test(configPatches.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching configPatches. No match found.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  
  public Integer getPriority() {
    return this.priority;
  }
  
  public A withPriority(Integer priority) {
    this.priority=priority; return (A) this;
  }
  
  public boolean hasPriority() {
    return this.priority != null;
  }
  
  public WorkloadSelector buildWorkloadSelector() {
    return this.workloadSelector!=null ?this.workloadSelector.build():null;
  }
  
  public A withWorkloadSelector(WorkloadSelector workloadSelector) {
    _visitables.get("workloadSelector").remove(this.workloadSelector);
    if (workloadSelector!=null){ this.workloadSelector= new WorkloadSelectorBuilder(workloadSelector); _visitables.get("workloadSelector").add(this.workloadSelector);} else { this.workloadSelector = null; _visitables.get("workloadSelector").remove(this.workloadSelector); } return (A) this;
  }
  
  public boolean hasWorkloadSelector() {
    return this.workloadSelector != null;
  }
  
  public WorkloadSelectorNested<A> withNewWorkloadSelector() {
    return new WorkloadSelectorNested(null);
  }
  
  public WorkloadSelectorNested<A> withNewWorkloadSelectorLike(WorkloadSelector item) {
    return new WorkloadSelectorNested(item);
  }
  
  public WorkloadSelectorNested<A> editWorkloadSelector() {
    return withNewWorkloadSelectorLike(java.util.Optional.ofNullable(buildWorkloadSelector()).orElse(null));
  }
  
  public WorkloadSelectorNested<A> editOrNewWorkloadSelector() {
    return withNewWorkloadSelectorLike(java.util.Optional.ofNullable(buildWorkloadSelector()).orElse(new WorkloadSelectorBuilder().build()));
  }
  
  public WorkloadSelectorNested<A> editOrNewWorkloadSelectorLike(WorkloadSelector item) {
    return withNewWorkloadSelectorLike(java.util.Optional.ofNullable(buildWorkloadSelector()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterSpecFluent that = (EnvoyFilterSpecFluent) o;
    if (!java.util.Objects.equals(configPatches, that.configPatches)) return false;
  
    if (!java.util.Objects.equals(priority, that.priority)) return false;
  
    if (!java.util.Objects.equals(workloadSelector, that.workloadSelector)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(configPatches,  priority,  workloadSelector,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configPatches != null && !configPatches.isEmpty()) { sb.append("configPatches:"); sb.append(configPatches + ","); }
    if (priority != null) { sb.append("priority:"); sb.append(priority + ","); }
    if (workloadSelector != null) { sb.append("workloadSelector:"); sb.append(workloadSelector); }
    sb.append("}");
    return sb.toString();
  }
  public class ConfigPatchesNested<N> extends EnvoyFilterEnvoyConfigObjectPatchFluent<ConfigPatchesNested<N>> implements Nested<N>{
    ConfigPatchesNested(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
      this.index = index;
      this.builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder;
    int index;
    
    public N and() {
      return (N) EnvoyFilterSpecFluent.this.setToConfigPatches(index,builder.build());
    }
    
    public N endConfigPatch() {
      return and();
    }
    
  
  }
  public class WorkloadSelectorNested<N> extends WorkloadSelectorFluent<WorkloadSelectorNested<N>> implements Nested<N>{
    WorkloadSelectorNested(WorkloadSelector item) {
      this.builder = new WorkloadSelectorBuilder(this, item);
    }
    WorkloadSelectorBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterSpecFluent.this.withWorkloadSelector(builder.build());
    }
    
    public N endWorkloadSelector() {
      return and();
    }
    
  
  }

}
